# Generated by Django 3.1.1 on 2020-10-03 12:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fleetpings", "0006_fleetdoctrine_restricted_to_group"),
    ]

    operations = [
        migrations.AlterField(
            model_name="discordpingtargets",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this configuration here if you want",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="fleetcomm",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this configuration here if you want",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="fleetdoctrine",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this configuration here if you want",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="fleettype",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this configuration here if you want",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="formuplocation",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this configuration here if you want",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="webhook",
            name="notes",
            field=models.TextField(
                blank=True,
                help_text="You can add notes about this webhook here if you want",
                null=True,
            ),
        ),
    ]
