{% load i18n %}

<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="fleetSrp">{% trans "SRP" %}</label>
    <div class="col-md-9">
        <select id="fleetSrp" name="fleetSrp" class="form-control">
            <option value="">{% trans "Please select" %}</option>
            <option value="Yes">{% trans "Yes" %}</option>
            <option value="No">{% trans "No" %}</option>
        </select>
    </div>
</div>
