{% load i18n %}

<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="fleetName">{% trans "Fleet Name" %}</label>
    <div class="col-md-9">
        <input id="fleetName" name="fleetName" type="text" class="form-control input-md">
    </div>
</div>
