{% extends 'allianceauth/base.html' %}

{% load i18n %}

{% block page_title %}{% trans "Fleet Ping Tool" %}{% endblock %}

{% block content %}
    <h1 class="page-header text-center">{% trans "Fleet Ping Tool" %}</h1>

    {% block details %}{% endblock %}
{% endblock %}
